@@ -60,6 +60,8 @@
 #'
 #' @return String by default of `string_output`, numeric otherwise.
 #'
+#' @name seq-decimal
+#'
 #' @seealso `seq_disperse()` for sequences centered around the input.
 #'
 #' @export
@@ -92,9 +94,10 @@
 #' seq_distance_df(.from = 0.43, .length_out = 5, sd = 0.08)
 
 
+#' @rdname seq-decimal
+#' @export
 
-
-seq_endpoint <- function(from, to, offset_from = 0, offset_to = 0,
+seq_endpoint <- function(from, to, offset_from = 0L, offset_to = 0L,
                          string_output = TRUE) {
 
   # A number's neighborhood depends on how many decimal places the number has.
@@ -107,9 +110,6 @@ seq_endpoint <- function(from, to, offset_from = 0, offset_to = 0,
   from_orig <- from
   to_orig   <- to
 
-  type_orig_from <- typeof(from)
-  type_orig_to   <- typeof(to)
-
   # After that, trailing zeros can safely be dropped because `from` and `to` are
   # only relevant in terms of their numeric values:
   from <- as.numeric(from)
@@ -117,12 +117,12 @@ seq_endpoint <- function(from, to, offset_from = 0, offset_to = 0,
 
   # The starting point and/or the endpoint might be offset by some non-zero
   # number of incremental steps. First, the starting point...
-  if (offset_from != 0) {
+  if (offset_from != 0L) {
     from <- from + (by * offset_from)
   }
 
   # ...and then, the endpoint:
-  if (offset_to != 0) {
+  if (offset_to != 0L) {
     to <- to + (by * offset_to)
   }
 
@@ -137,9 +137,9 @@ seq_endpoint <- function(from, to, offset_from = 0, offset_to = 0,
 
   # Hackish way of conveying to `manage_string_output_seq()` whether or not
   # either of `from` and `to` was specified as a string, or else as a double:
-  if (is.character(from_orig) | is.character(to_orig)) {
+  if (is.character(from_orig) || is.character(to_orig)) {
     from <- as.character(from)
-  } else if (is.double(from_orig) | is.double(to_orig)) {
+  } else if (is.double(from_orig) || is.double(to_orig)) {
     from <- as.double(from)
   } else {
     from <- as.integer(from)
@@ -158,11 +158,11 @@ seq_endpoint <- function(from, to, offset_from = 0, offset_to = 0,
 
 
 
-#' @rdname seq_endpoint
+#' @rdname seq-decimal
 #' @export
 
-seq_distance <- function(from, by = NULL, length_out = 10, dir = 1,
-                         offset_from = 0, string_output = TRUE) {
+seq_distance <- function(from, by = NULL, length_out = 10L, dir = 1,
+                         offset_from = 0L, string_output = TRUE) {
 
   # If the step size by which the sequence progresses (`by`) was not manually
   # chosen as in `seq()`, it is determined by the number of decimal places in
@@ -171,14 +171,13 @@ seq_distance <- function(from, by = NULL, length_out = 10, dir = 1,
     digits <- decimal_places_scalar(from)
     by <- 1 / (10 ^ digits)
   } else {
-    check_length(by, 1)
+    check_length(by, 1L)
     check_type(by, c("integer", "double"))
     digits <- decimal_places_scalar(by)
   }
 
   # Record if `from` was specified as string; relevant for `string_output`:
   from_orig <- from
-  type_orig_from <- typeof(from)
 
   # After that, trailing zeros can safely be dropped because `from` is only
   # relevant in terms of its numeric value:
@@ -186,15 +185,15 @@ seq_distance <- function(from, by = NULL, length_out = 10, dir = 1,
 
   # The starting point might be offset by some non-zero number of incremental
   # steps (the default is 0, in which case this does nothing):
-  if (offset_from != 0) {
+  if (offset_from != 0L) {
     from <- from + (by * offset_from)
   }
 
   # The distance between the starting point and the end point follows from the
   # step size in conjunction with the desired output length (`length_out`).
-  # However, the starting point is also part of the sequence, so it needs to be
+  # However, the starting point is also part of the sequence, so it must be
   # compensated by subtracting 1 from the desired length:
-  distance <- by * (length_out - 1)
+  distance <- by * (length_out - 1L)
 
   # The endpoint of the sequence, `to`, is simply the starting point plus the
   # distance. However, that's just the default. If `dir` was set to `-1`, it
@@ -208,8 +207,8 @@ seq_distance <- function(from, by = NULL, length_out = 10, dir = 1,
     by <- -by
   } else {
     cli::cli_abort(c(
-      "`dir` given as `{dir}`",
-      "x" = "`dir` needs to be either `1` or `-1`."
+      "!" = "`dir` must be either `1` or `-1`.",
+      "x" = "It was given as `{dir}`."
     ))
   }
 
@@ -232,10 +231,10 @@ seq_distance <- function(from, by = NULL, length_out = 10, dir = 1,
 
 
 
-#' @rdname seq_endpoint
+#' @rdname seq-decimal
 #' @export
 
-seq_endpoint_df <- function(.from, .to, ..., .offset_from = 0, .offset_to = 0,
+seq_endpoint_df <- function(.from, .to, ..., .offset_from = 0L, .offset_to = 0L,
                             .string_output = TRUE) {
 
   # Call the basic function to generate the sequence:
@@ -252,7 +251,7 @@ seq_endpoint_df <- function(.from, .to, ..., .offset_from = 0, .offset_to = 0,
   # additional columns into it. Then, add a special class to the tibble, but
   # only to pass messages between (1) here, (2) the testing function, and (3)
   # `seq_test_ranking()`. Finally, return the resulting tibble:
-  if (length(further_cols) > 0) {
+  if (length(further_cols) > 0L) {
     out <- tibble::tibble(x, !!!further_cols)
   } else {
     out <- tibble::tibble(x)
@@ -265,11 +264,11 @@ seq_endpoint_df <- function(.from, .to, ..., .offset_from = 0, .offset_to = 0,
 
 
 
-#' @rdname seq_endpoint
+#' @rdname seq-decimal
 #' @export
 
-seq_distance_df <- function(.from, .by = NULL, ..., .length_out = 10, .dir = 1,
-                            .offset_from = 0, .string_output = TRUE) {
+seq_distance_df <- function(.from, .by = NULL, ..., .length_out = 10L, .dir = 1,
+                            .offset_from = 0L, .string_output = TRUE) {
 
   # Call the basic function to generate the sequence:
   x <- seq_distance(
@@ -285,7 +284,7 @@ seq_distance_df <- function(.from, .by = NULL, ..., .length_out = 10, .dir = 1,
   # additional columns into it. Then, add a special class to the tibble, but
   # only to pass messages between (1) here, (2) the testing function, and (3)
   # `seq_test_ranking()`. Finally, return the resulting tibble:
-  if (length(further_cols) > 0) {
+  if (length(further_cols) > 0L) {
     out <- tibble::tibble(x, !!!further_cols)
   } else {
     out <- tibble::tibble(x)
