@@ -24,7 +24,7 @@ test_that("It has correct column names", {
 })
 
 
-pigs_tested_transformed <- split_by_parens(pigs, .transform = TRUE)
+pigs_tested_transformed <- split_by_parens(pigs, transform = TRUE)
 
 x_expected  <- restore_zeros(c(0.09, 0.19, 0.62, 0.15, 0.19, 0.53, 0.50, 0.57))
 sd_expected <- restore_zeros(c(0.21, 0.28, 0.16, 0.35, 0.13, 0.10, 0.11, 0.16))
@@ -37,18 +37,18 @@ test_that("It has correct values", {
 
 pigs_brackets <- pigs %>%
   dplyr::mutate(
-    dplyr::across(everything(), stringr::str_replace, "\\(", "["),
-    dplyr::across(everything(), stringr::str_replace, "\\)", "]")
+    dplyr::across(everything(), function(x) stringr::str_replace(x, "\\(", "[")),
+    dplyr::across(everything(), function(x) stringr::str_replace(x, "\\)", "]"))
   )
 
 pigs_braces <- pigs %>%
   dplyr::mutate(
-    dplyr::across(everything(), stringr::str_replace, "\\(", "{"),
-    dplyr::across(everything(), stringr::str_replace, "\\)", "}")
+    dplyr::across(everything(), function(x) stringr::str_replace(x, "\\(", "{")),
+    dplyr::across(everything(), function(x) stringr::str_replace(x, "\\)", "}"))
   )
 
-pigs_brackets_tested <- split_by_parens(pigs_brackets, .sep = "brackets")
-pigs_braces_tested <- split_by_parens(pigs_braces, .sep = "braces")
+pigs_brackets_tested <- split_by_parens(pigs_brackets, sep = "brackets")
+pigs_braces_tested <- split_by_parens(pigs_braces, sep = "braces")
 
 test_that("The function works with square brackets as with parentheses", {
   pigs_tested[1] %>% expect_equal(pigs_brackets_tested[1])
@@ -75,6 +75,26 @@ test_that("The function works with curly braces as with square brackets", {
 test_that("named but non-formal arguments are an error", {
   # These should be caught by `ellipsis::check_dots_unnamed()`.
   pigs %>% split_by_parens(abc = 5)         %>% expect_error()
-  pigs %>% split_by_parens(.no_arg = hello) %>% expect_error()
+  pigs %>% split_by_parens(no_arg = hello)  %>% expect_error()
 })
 
+test_that("using the dots, `...`, is an error", {
+  pigs %>% split_by_parens(.transform = TRUE)                 %>% expect_error()
+  pigs %>% split_by_parens(.transform = TRUE, .col1 = "mean") %>% expect_error()
+  pigs %>% split_by_parens(wooh = 4)                          %>% expect_error()
+})
+
+
+pigs_wider <- pigs %>% dplyr::mutate(letters = letters[1:4])
+
+test_that("non-`sep` columns are handled correctly with `check_sep = TRUE` (the default)", {
+  pigs_wider %>% split_by_parens() %>% expect_warning()
+  pigs_wider %>% split_by_parens() %>% suppressWarnings() %>% ncol() %>% expect_equal(5L)
+})
+
+test_that("non-`sep` columns are handled correctly with `check_sep = FALSE", {
+  pigs_wider %>% split_by_parens(check_sep = FALSE) %>% expect_warning()
+  pigs_wider %>% split_by_parens(check_sep = FALSE) %>% suppressWarnings() %>% ncol() %>% expect_equal(6L)
+})
+
+
